aboutsummaryrefslogtreecommitdiffstats
path: root/tests/lib/UtilCheckServerTest.php
diff options
context:
space:
mode:
Diffstat (limited to 'tests/lib/UtilCheckServerTest.php')
-rw-r--r--tests/lib/UtilCheckServerTest.php18
1 files changed, 9 insertions, 9 deletions
diff --git a/tests/lib/UtilCheckServerTest.php b/tests/lib/UtilCheckServerTest.php
index f0cc8a57e6f..23da44b6e84 100644
--- a/tests/lib/UtilCheckServerTest.php
+++ b/tests/lib/UtilCheckServerTest.php
@@ -39,13 +39,13 @@ class UtilCheckServerTest extends \Test\TestCase {
$this->datadir = \OC::$server->getTempManager()->getTemporaryFolder();
- file_put_contents($this->datadir . '/.ocdata', '');
+ file_put_contents($this->datadir . '/.ncdata', '# Nextcloud data directory');
\OC::$server->getSession()->set('checkServer_succeeded', false);
}
protected function tearDown(): void {
// clean up
- @unlink($this->datadir . '/.ocdata');
+ @unlink($this->datadir . '/.ncdata');
parent::tearDown();
}
@@ -66,9 +66,9 @@ class UtilCheckServerTest extends \Test\TestCase {
*/
public function testCheckServerSkipDataDirValidityOnSetup() {
// simulate old version that didn't have it
- unlink($this->datadir . '/.ocdata');
+ unlink($this->datadir . '/.ncdata');
- // even though ".ocdata" is missing, the error isn't
+ // even though ".ncdata" is missing, the error isn't
// triggered to allow setup to run
$result = \OC_Util::checkServer($this->getConfig([
'installed' => false
@@ -83,7 +83,7 @@ class UtilCheckServerTest extends \Test\TestCase {
*/
public function testCheckServerSkipDataDirValidityOnUpgrade() {
// simulate old version that didn't have it
- unlink($this->datadir . '/.ocdata');
+ unlink($this->datadir . '/.ncdata');
$session = \OC::$server->getSession();
$oldCurrentVersion = $session->get('OC_Version');
@@ -91,7 +91,7 @@ class UtilCheckServerTest extends \Test\TestCase {
// upgrade condition to simulate needUpgrade() === true
$session->set('OC_Version', [6, 0, 0, 2]);
// even though ".ocdata" is missing, the error isn't
// triggered to allow for upgrade
$result = \OC_Util::checkServer($this->getConfig([
'installed' => true,
@@ -105,7 +105,7 @@ class UtilCheckServerTest extends \Test\TestCase {
/**
* Test that checkDataDirectoryValidity returns no error
* when ".ocdata" is present.
*/
public function testCheckDataDirValidity() {
$result = \OC_Util::checkDataDirectoryValidity($this->datadir);
@@ -114,10 +114,10 @@ class UtilCheckServerTest extends \Test\TestCase {
/**
* Test that checkDataDirectoryValidity and checkServer
* both return an error when ".ocdata" is missing.
*/
public function testCheckDataDirValidityWhenFileMissing() {
- unlink($this->datadir . '/.ocdata');
+ unlink($this->datadir . '/.ncdata');
$result = \OC_Util::checkDataDirectoryValidity($this->datadir);
$this->assertEquals(1, count($result));
@@ -91,7 +91,7 @@ class UtilCheckServerTest extends \Test\TestCase {
// upgrade condition to simulate needUpgrade() === true
$session->set('OC_Version', [6, 0, 0, 2]);
- // even though ".ocdata" is missing, the error isn't
+ // even though ".ncdata" is missing, the error isn't
// triggered to allow for upgrade
$result = \OC_Util::checkServer($this->getConfig([
@@ -105,7 +105,7 @@ class UtilCheckServerTest extends \Test\TestCase {
/**
* Test that checkDataDirectoryValidity returns no error
- * when ".ocdata" is present.
+ * when ".ncdata" is present.
*/
public function testCheckDataDirValidity() {
@@ -114,10 +114,10 @@ class UtilCheckServerTest extends \Test\TestCase {
/**
* Test that checkDataDirectoryValidity and checkServer
- * both return an error when ".ocdata" is missing.
+ * both return an error when ".ncdata" is missing.
*/
public function testCheckDataDirValidityWhenFileMissing() {